==> haskell-getopt-generics-0.13.0.4-115-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-getopt-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 getopt-generics
version:              0.13.0.4
visibility:           public
id:                   getopt-generics-0.13.0.4-JaZc4USTAx0LhV02aIlesb
key:                  getopt-generics-0.13.0.4-JaZc4USTAx0LhV02aIlesb
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  9611fc53e66a7b2b7f92b19f81897728
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.0.2/site-local/getopt-generics-0.13.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/getopt-generics-0.13.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/getopt-generics-0.13.0.4
hs-libraries:         HSgetopt-generics-0.13.0.4-JaZc4USTAx0LhV02aIlesb
depends:
    base-4.15.1.0 base-compat-0.11.2-D5DT1MGmUKa4Ww8Uu5S4h5
    base-orphans-0.8.5-8t7HJSExOIuF1OVuzWMxiY
    generics-sop-0.5.1.1-3bFDOH8KLJNGftETI5ShQz
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-getopt-generics-0.13.0.4-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-getopt-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 getopt-generics
version:              0.13.0.4
visibility:           public
id:                   getopt-generics-0.13.0.4-8DHsfcmSm4lD0V2P6qgsJx
key:                  getopt-generics-0.13.0.4-8DHsfcmSm4lD0V2P6qgsJx
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  c401d0e5dc48de169e7de4bedaa15068
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.0.2/site-local/getopt-generics-0.13.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/getopt-generics-0.13.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/getopt-generics-0.13.0.4
hs-libraries:         HSgetopt-generics-0.13.0.4-8DHsfcmSm4lD0V2P6qgsJx
depends:
    base-4.15.1.0 base-compat-0.11.2-D5DT1MGmUKa4Ww8Uu5S4h5
    base-orphans-0.8.6-58gtAdHVC823tbAP7RSB62
    generics-sop-0.5.1.2-2vbZE2EqscwJl8mUOyVifJ
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
